@@ -1,16 +1,15 @@
 #
 # port.rb
 #
-# Copyright (c) 1998-2003 Minero Aoki <aamine@loveruby.net>
+# Copyright (c) 1998-2004 Minero Aoki
 #
 # This program is free software.
 # You can distribute/modify this program under the terms of
-# the GNU Lesser General Public License version 2 or later.
+# the GNU Lesser General Public License version 2.1.
 #
 
 require 'tmail/stringio'
 
-
 module TMail
 
   class Port
@@ -26,27 +25,28 @@ module TMail
 
   class FilePort < Port
 
-    def initialize( fname )
-      @filename = File.expand_path(fname)
+    def initialize(fname)
+      @path = File.expand_path(fname)
       super()
     end
 
-    attr_reader :filename
+    attr_reader :path
+    alias filename path
 
-    alias ident filename
+    alias ident path
 
-    def ==( other )
-      other.respond_to?(:filename) and @filename == other.filename
+    def ==(other)
+      other.respond_to?(:path) and @path == other.path
     end
 
     alias eql? ==
 
     def hash
-      @filename.hash
+      @path.hash
     end
 
     def inspect
-      "#<#{self.class}:#{@filename}>"
+      "#<#{self.class} #{@path}>"
     end
 
     def reproducible?
@@ -54,55 +54,56 @@ module TMail
     end
 
     def size
-      File.size @filename
+      File.size(@path)
     end
 
 
-    def ropen( &block )
-      File.open(@filename, &block)
+    def ropen(&block)
+      File.open(@path, &block)
     end
 
-    def wopen( &block )
-      File.open(@filename, 'w', &block)
+    def wopen(&block)
+      File.open(@path, 'w', &block)
     end
 
-    def aopen( &block )
-      File.open(@filename, 'a', &block)
+    def aopen(&block)
+      File.open(@path, 'a', &block)
     end
 
 
     def read_all
       ropen {|f|
-          return f.read
+        return f.read
       }
     end
 
 
     def remove
-      File.unlink @filename
+      File.unlink @path
     end
 
-    def move_to( port )
+    def move_to(port)
       begin
-        File.link @filename, port.filename
+        File.link @path, port.path
       rescue Errno::EXDEV
         copy_to port
       end
-      File.unlink @filename
+      File.unlink @path
     end
 
     alias mv move_to
 
-    def copy_to( port )
-      if FilePort === port
-        copy_file @filename, port.filename
+    def copy_to(port)
+      if port.is_a?(FilePort)
+        copy_file @path, port.path
       else
-        File.open(@filename) {|r|
-        port.wopen {|w|
+        File.open(@path) {|r|
+          port.wopen {|w|
             while s = r.sysread(4096)
               w.write << s
             end
-        } }
+          }
+        }
       end
     end
 
@@ -110,20 +111,14 @@ module TMail
 
     private
 
-    # from fileutils.rb
-    def copy_file( src, dest )
-      st = r = w = nil
-
+    def copy_file(src, dest)
       File.open(src,  'rb') {|r|
-      File.open(dest, 'wb') {|w|
-          st = r.stat
-          begin
-            while true
-              w.write r.sysread(st.blksize)
-            end
-          rescue EOFError
+        File.open(dest, 'wb') {|w|
+          while str = r.read(2048)
+            w.write str
           end
-      } }
+        }
+      }
     end
 
   end
@@ -131,7 +126,7 @@ module TMail
 
   module MailFlags
 
-    def seen=( b )
+    def seen=(b)
       set_status 'S', b
     end
 
@@ -139,7 +134,7 @@ module TMail
       get_status 'S'
     end
 
-    def replied=( b )
+    def replied=(b)
       set_status 'R', b
     end
 
@@ -147,7 +142,7 @@ module TMail
       get_status 'R'
     end
 
-    def flagged=( b )
+    def flagged=(b)
       set_status 'F', b
     end
 
@@ -157,7 +152,7 @@ module TMail
 
     private
 
-    def procinfostr( str, tag, true_p )
+    def procinfostr(str, tag, true_p)
       a = str.upcase.split(//)
       a.push true_p ? tag : nil
       a.delete tag unless true_p
@@ -173,22 +168,22 @@ module TMail
 
     private
     
-    def set_status( tag, flag )
+    def set_status(tag, flag)
       begin
-        tmpfile = @filename + '.tmailtmp.' + $$.to_s
+        tmpfile = "#{@path}.tmailtmp.#{$$}"
         File.open(tmpfile, 'w') {|f|
           write_status f, tag, flag
         }
-        File.unlink @filename
-        File.link tmpfile, @filename
+        File.unlink @path
+        File.link tmpfile, @path
       ensure
         File.unlink tmpfile
       end
     end
 
-    def write_status( f, tag, flag )
+    def write_status(f, tag, flag)
       stat = ''
-      File.open(@filename) {|r|
+      File.open(@path) {|r|
         while line = r.gets
           if line.strip.empty?
             break
@@ -209,8 +204,8 @@ module TMail
       }
     end
 
-    def get_status( tag )
-      File.foreach(@filename) {|line|
+    def get_status(tag)
+      File.foreach(@path) {|line|
         return false if line.strip.empty?
         if m = /\AX-TMail-Status:/i.match(line)
           return m.post_match.strip.include?(tag[0])
@@ -225,18 +220,18 @@ module TMail
   class MaildirPort < FilePort
 
     def move_to_new
-      new = replace_dir(@filename, 'new')
-      File.rename @filename, new
-      @filename = new
+      new = replace_dir(@path, 'new')
+      File.rename @path, new
+      @path = new
     end
 
     def move_to_cur
-      new = replace_dir(@filename, 'cur')
-      File.rename @filename, new
-      @filename = new
+      new = replace_dir(@path, 'cur')
+      File.rename @path, new
+      @path = new
     end
 
-    def replace_dir( path, dir )
+    def replace_dir(path, dir)
       "#{File.dirname File.dirname(path)}/#{dir}/#{File.basename path}"
     end
     private :replace_dir
@@ -248,23 +243,23 @@ module TMail
 
     MAIL_FILE = /\A(\d+\.[\d_]+\.[^:]+)(?:\:(\d),(\w+)?)?\z/
 
-    def set_status( tag, flag )
-      if m = MAIL_FILE.match(File.basename(@filename))
+    def set_status(tag, flag)
+      if m = MAIL_FILE.match(File.basename(@path))
         s, uniq, type, info, = m.to_a
         return if type and type != '2'  # do not change anything
-        newname = File.dirname(@filename) + '/' +
+        newname = File.dirname(@path) + '/' +
                   uniq + ':2,' + procinfostr(info.to_s, tag, flag)
       else
-        newname = @filename + ':2,' + tag
+        newname = @path + ':2,' + tag
       end
 
-      File.link @filename, newname
-      File.unlink @filename
-      @filename = newname
+      File.link @path, newname
+      File.unlink @path
+      @path = newname
     end
 
-    def get_status( tag )
-      m = MAIL_FILE.match(File.basename(@filename)) or return false
+    def get_status(tag)
+      m = MAIL_FILE.match(File.basename(@path)) or return false
       m[2] == '2' and m[3].to_s.include?(tag[0])
     end
   
@@ -277,7 +272,7 @@ module TMail
 
   class StringPort < Port
 
-    def initialize( str = '' )
+    def initialize(str = '')
       @buffer = str
       super()
     end
@@ -296,35 +291,36 @@ module TMail
       @buffer.size
     end
 
-    def ==( other )
-      StringPort === other and @buffer.equal? other.string
+    def ==(other)
+      other.is_a?(StringPort) and @buffer.equal?(other.string)
     end
 
     alias eql? ==
 
     def hash
-      @buffer.id.hash
+      @buffer.object_id.hash
     end
 
     def inspect
-      "#<#{self.class}:id=#{sprintf '0x%x', @buffer.id}>"
+      "#<#{self.class}:id=#{sprintf '0x%x', @buffer.object_id}>"
     end
 
     def reproducible?
       true
     end
 
-    def ropen( &block )
-      @buffer or raise Errno::ENOENT, "#{inspect} is already removed"
+    def ropen(&block)
+      # FIXME: Should we raise ENOENT?
+      raise Errno::ENOENT, "#{inspect} is already removed" unless @buffer
       StringInput.open(@buffer, &block)
     end
 
-    def wopen( &block )
+    def wopen(&block)
       @buffer = ''
       StringOutput.new(@buffer, &block)
     end
 
-    def aopen( &block )
+    def aopen(&block)
       @buffer ||= ''
       StringOutput.new(@buffer, &block)
     end
@@ -335,18 +331,20 @@ module TMail
 
     alias rm remove
 
-    def copy_to( port )
+    def copy_to(port)
       port.wopen {|f|
-          f.write @buffer
+        f.write @buffer
       }
     end
 
     alias cp copy_to
 
-    def move_to( port )
-      if StringPort === port
-        str = @buffer
-        port.instance_eval { @buffer = str }
+    def move_to(port)
+      if port.is_a?(StringPort)
+        tmp = @buffer
+        port.instance_eval {
+          @buffer = tmp
+        }
       else
         copy_to port
       end
